@@ -43,3 +43,25 @@ test_that("basic plot test, layout 2", {
     }
   )
 })
+
+test_that("basic plot test, spheres", {
+  g <- make_graph(c(1, 2, 1, 1, 2, 3), directed = F)
+  g$layout <- structure(
+    c(
+      1.17106961533433,
+      1.63885278868168,
+      2.10732892696401,
+      3.91718168529106,
+      2.87660789399794,
+      1.83449260993935
+    ),
+    dim = 3:2
+  )
+
+  vdiffr::expect_doppelganger(
+    "Basic graph, spheres",
+    function() {
+      plot(g, vertex.shape = "sphere", vertex.size = 100)
+    }
+  )
+})
